@@ -3,14 +3,14 @@
 # Copyright (C) PyZMQ Developers
 # Distributed under the terms of the Modified BSD License.
 
-from typing import Optional, Tuple, Union
+from typing import Tuple, Union
 
 from zmq.backend import zmq_version_info
 
 
-VERSION_MAJOR = 21
-VERSION_MINOR = 0
-VERSION_PATCH = 2
+VERSION_MAJOR = 22
+VERSION_MINOR = 2
+VERSION_PATCH = 1
 VERSION_EXTRA = ""
 __version__ = '%i.%i.%i' % (VERSION_MAJOR, VERSION_MINOR, VERSION_PATCH)
 
